@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 import functools
 import re
@@ -22,19 +20,18 @@ from typing import Dict, Sequence, Tuple, Type, Union
 import pkg_resources
 
 import google.api_core.client_options as ClientOptions  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.oauth2 import service_account  # type: ignore
 
 from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.devtools.cloudbuild_v1.services.cloud_build import pagers
 from google.cloud.devtools.cloudbuild_v1.types import cloudbuild
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import CloudBuildTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc_asyncio import CloudBuildGrpcAsyncIOTransport
 from .client import CloudBuildClient
@@ -68,25 +65,24 @@ class CloudBuildAsyncClient:
     parse_service_account_path = staticmethod(
         CloudBuildClient.parse_service_account_path
     )
-
+    subscription_path = staticmethod(CloudBuildClient.subscription_path)
+    parse_subscription_path = staticmethod(CloudBuildClient.parse_subscription_path)
+    topic_path = staticmethod(CloudBuildClient.topic_path)
+    parse_topic_path = staticmethod(CloudBuildClient.parse_topic_path)
     common_billing_account_path = staticmethod(
         CloudBuildClient.common_billing_account_path
     )
     parse_common_billing_account_path = staticmethod(
         CloudBuildClient.parse_common_billing_account_path
     )
-
     common_folder_path = staticmethod(CloudBuildClient.common_folder_path)
     parse_common_folder_path = staticmethod(CloudBuildClient.parse_common_folder_path)
-
     common_organization_path = staticmethod(CloudBuildClient.common_organization_path)
     parse_common_organization_path = staticmethod(
         CloudBuildClient.parse_common_organization_path
     )
-
     common_project_path = staticmethod(CloudBuildClient.common_project_path)
     parse_common_project_path = staticmethod(CloudBuildClient.parse_common_project_path)
-
     common_location_path = staticmethod(CloudBuildClient.common_location_path)
     parse_common_location_path = staticmethod(
         CloudBuildClient.parse_common_location_path
@@ -94,7 +90,8 @@ class CloudBuildAsyncClient:
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -109,7 +106,7 @@ class CloudBuildAsyncClient:
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -126,7 +123,7 @@ class CloudBuildAsyncClient:
 
     @property
     def transport(self) -> CloudBuildTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
             CloudBuildTransport: The transport used by the client instance.
@@ -140,12 +137,12 @@ class CloudBuildAsyncClient:
     def __init__(
         self,
         *,
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         transport: Union[str, CloudBuildTransport] = "grpc_asyncio",
         client_options: ClientOptions = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the cloud build client.
+        """Instantiates the cloud build client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -177,7 +174,6 @@ class CloudBuildAsyncClient:
             google.auth.exceptions.MutualTlsChannelError: If mutual TLS transport
                 creation failed for any reason.
         """
-
         self._client = CloudBuildClient(
             credentials=credentials,
             transport=transport,
@@ -214,7 +210,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``build`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -266,7 +261,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
         if build is not None:
@@ -323,7 +317,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -371,7 +364,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
         if id is not None:
@@ -386,7 +378,8 @@ class CloudBuildAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -429,7 +422,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -458,7 +450,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
         if filter is not None:
@@ -473,7 +464,8 @@ class CloudBuildAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -518,7 +510,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -566,7 +557,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
         if id is not None:
@@ -642,7 +632,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -694,7 +683,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
         if id is not None:
@@ -752,7 +740,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``trigger`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -780,7 +767,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
         if trigger is not None:
@@ -832,7 +818,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``trigger_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -860,7 +845,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
         if trigger_id is not None:
@@ -875,7 +859,8 @@ class CloudBuildAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -913,7 +898,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -942,7 +926,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
 
@@ -955,7 +938,8 @@ class CloudBuildAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -1004,7 +988,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``trigger_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1025,7 +1008,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
         if trigger_id is not None:
@@ -1040,7 +1022,8 @@ class CloudBuildAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -1089,7 +1072,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``trigger`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1117,7 +1099,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
         if trigger_id is not None:
@@ -1171,7 +1152,6 @@ class CloudBuildAsyncClient:
                 This corresponds to the ``source`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1223,7 +1203,6 @@ class CloudBuildAsyncClient:
 
         # If we have keyword arguments corresponding to fields on the
         # request, apply these.
-
         if project_id is not None:
             request.project_id = project_id
         if trigger_id is not None:
@@ -1269,7 +1248,6 @@ class CloudBuildAsyncClient:
                 The request object. ReceiveTriggerWebhookRequest
                 [Experimental] is the request object accepted by the
                 ReceiveTriggerWebhook method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1283,7 +1261,6 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = cloudbuild.ReceiveTriggerWebhookRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -1317,7 +1294,6 @@ class CloudBuildAsyncClient:
             request (:class:`google.cloud.devtools.cloudbuild_v1.types.CreateWorkerPoolRequest`):
                 The request object. Request to create a new
                 `WorkerPool`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1341,7 +1317,6 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = cloudbuild.CreateWorkerPoolRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -1374,7 +1349,6 @@ class CloudBuildAsyncClient:
             request (:class:`google.cloud.devtools.cloudbuild_v1.types.GetWorkerPoolRequest`):
                 The request object. Request to get a `WorkerPool` with
                 the specified name.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1398,7 +1372,6 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = cloudbuild.GetWorkerPoolRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -1410,7 +1383,8 @@ class CloudBuildAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
@@ -1439,7 +1413,6 @@ class CloudBuildAsyncClient:
         Args:
             request (:class:`google.cloud.devtools.cloudbuild_v1.types.DeleteWorkerPoolRequest`):
                 The request object. Request to delete a `WorkerPool`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1447,7 +1420,6 @@ class CloudBuildAsyncClient:
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-
         request = cloudbuild.DeleteWorkerPoolRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -1478,7 +1450,6 @@ class CloudBuildAsyncClient:
         Args:
             request (:class:`google.cloud.devtools.cloudbuild_v1.types.UpdateWorkerPoolRequest`):
                 The request object. Request to update a `WorkerPool`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1502,7 +1473,6 @@ class CloudBuildAsyncClient:
 
         """
         # Create or coerce a protobuf request object.
-
         request = cloudbuild.UpdateWorkerPoolRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -1534,7 +1504,6 @@ class CloudBuildAsyncClient:
         Args:
             request (:class:`google.cloud.devtools.cloudbuild_v1.types.ListWorkerPoolsRequest`):
                 The request object. Request to list `WorkerPools`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1546,7 +1515,6 @@ class CloudBuildAsyncClient:
                 Response containing existing WorkerPools.
         """
         # Create or coerce a protobuf request object.
-
         request = cloudbuild.ListWorkerPoolsRequest(request)
 
         # Wrap the RPC method; this adds retry and timeout information,
@@ -1558,7 +1526,8 @@ class CloudBuildAsyncClient:
                 maximum=60.0,
                 multiplier=1.3,
                 predicate=retries.if_exception_type(
-                    exceptions.DeadlineExceeded, exceptions.ServiceUnavailable,
+                    core_exceptions.DeadlineExceeded,
+                    core_exceptions.ServiceUnavailable,
                 ),
                 deadline=600.0,
             ),
