@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,7 +13,6 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 from collections import OrderedDict
 from distutils import util
 import os
@@ -23,10 +21,10 @@ from typing import Callable, Dict, Optional, Sequence, Tuple, Type, Union
 import pkg_resources
 
 from google.api_core import client_options as client_options_lib  # type: ignore
-from google.api_core import exceptions  # type: ignore
+from google.api_core import exceptions as core_exceptions  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
 from google.api_core import retry as retries  # type: ignore
-from google.auth import credentials  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport import mtls  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 from google.auth.exceptions import MutualTLSChannelError  # type: ignore
@@ -36,9 +34,8 @@ from google.api_core import operation  # type: ignore
 from google.api_core import operation_async  # type: ignore
 from google.cloud.devtools.cloudbuild_v1.services.cloud_build import pagers
 from google.cloud.devtools.cloudbuild_v1.types import cloudbuild
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
-
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 from .transports.base import CloudBuildTransport, DEFAULT_CLIENT_INFO
 from .transports.grpc import CloudBuildGrpcTransport
 from .transports.grpc_asyncio import CloudBuildGrpcAsyncIOTransport
@@ -57,7 +54,7 @@ class CloudBuildClientMeta(type):
     _transport_registry["grpc_asyncio"] = CloudBuildGrpcAsyncIOTransport
 
     def get_transport_class(cls, label: str = None,) -> Type[CloudBuildTransport]:
-        """Return an appropriate transport class.
+        """Returns an appropriate transport class.
 
         Args:
             label: The name of the desired transport. If none is
@@ -88,7 +85,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
     @staticmethod
     def _get_default_mtls_endpoint(api_endpoint):
-        """Convert api endpoint to mTLS endpoint.
+        """Converts api endpoint to mTLS endpoint.
+
         Convert "*.sandbox.googleapis.com" and "*.googleapis.com" to
         "*.mtls.sandbox.googleapis.com" and "*.mtls.googleapis.com" respectively.
         Args:
@@ -122,7 +120,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
     @classmethod
     def from_service_account_info(cls, info: dict, *args, **kwargs):
-        """Creates an instance of this client using the provided credentials info.
+        """Creates an instance of this client using the provided credentials
+            info.
 
         Args:
             info (dict): The service account private key info.
@@ -139,7 +138,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
     @classmethod
     def from_service_account_file(cls, filename: str, *args, **kwargs):
         """Creates an instance of this client using the provided credentials
-        file.
+            file.
 
         Args:
             filename (str): The path to the service account private key json
@@ -158,47 +157,48 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
     @property
     def transport(self) -> CloudBuildTransport:
-        """Return the transport used by the client instance.
+        """Returns the transport used by the client instance.
 
         Returns:
-            CloudBuildTransport: The transport used by the client instance.
+            CloudBuildTransport: The transport used by the client
+                instance.
         """
         return self._transport
 
     @staticmethod
     def build_path(project: str, build: str,) -> str:
-        """Return a fully-qualified build string."""
+        """Returns a fully-qualified build string."""
         return "projects/{project}/builds/{build}".format(project=project, build=build,)
 
     @staticmethod
     def parse_build_path(path: str) -> Dict[str, str]:
-        """Parse a build path into its component segments."""
+        """Parses a build path into its component segments."""
         m = re.match(r"^projects/(?P<project>.+?)/builds/(?P<build>.+?)$", path)
         return m.groupdict() if m else {}
 
     @staticmethod
     def build_trigger_path(project: str, trigger: str,) -> str:
-        """Return a fully-qualified build_trigger string."""
+        """Returns a fully-qualified build_trigger string."""
         return "projects/{project}/triggers/{trigger}".format(
             project=project, trigger=trigger,
         )
 
     @staticmethod
     def parse_build_trigger_path(path: str) -> Dict[str, str]:
-        """Parse a build_trigger path into its component segments."""
+        """Parses a build_trigger path into its component segments."""
         m = re.match(r"^projects/(?P<project>.+?)/triggers/(?P<trigger>.+?)$", path)
         return m.groupdict() if m else {}
 
     @staticmethod
     def crypto_key_path(project: str, location: str, keyring: str, key: str,) -> str:
-        """Return a fully-qualified crypto_key string."""
+        """Returns a fully-qualified crypto_key string."""
         return "projects/{project}/locations/{location}/keyRings/{keyring}/cryptoKeys/{key}".format(
             project=project, location=location, keyring=keyring, key=key,
         )
 
     @staticmethod
     def parse_crypto_key_path(path: str) -> Dict[str, str]:
-        """Parse a crypto_key path into its component segments."""
+        """Parses a crypto_key path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/locations/(?P<location>.+?)/keyRings/(?P<keyring>.+?)/cryptoKeys/(?P<key>.+?)$",
             path,
@@ -207,14 +207,14 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
     @staticmethod
     def secret_version_path(project: str, secret: str, version: str,) -> str:
-        """Return a fully-qualified secret_version string."""
+        """Returns a fully-qualified secret_version string."""
         return "projects/{project}/secrets/{secret}/versions/{version}".format(
             project=project, secret=secret, version=version,
         )
 
     @staticmethod
     def parse_secret_version_path(path: str) -> Dict[str, str]:
-        """Parse a secret_version path into its component segments."""
+        """Parses a secret_version path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/secrets/(?P<secret>.+?)/versions/(?P<version>.+?)$",
             path,
@@ -223,23 +223,49 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
     @staticmethod
     def service_account_path(project: str, service_account: str,) -> str:
-        """Return a fully-qualified service_account string."""
+        """Returns a fully-qualified service_account string."""
         return "projects/{project}/serviceAccounts/{service_account}".format(
             project=project, service_account=service_account,
         )
 
     @staticmethod
     def parse_service_account_path(path: str) -> Dict[str, str]:
-        """Parse a service_account path into its component segments."""
+        """Parses a service_account path into its component segments."""
         m = re.match(
             r"^projects/(?P<project>.+?)/serviceAccounts/(?P<service_account>.+?)$",
             path,
         )
         return m.groupdict() if m else {}
 
+    @staticmethod
+    def subscription_path(project: str, subscription: str,) -> str:
+        """Returns a fully-qualified subscription string."""
+        return "projects/{project}/subscriptions/{subscription}".format(
+            project=project, subscription=subscription,
+        )
+
+    @staticmethod
+    def parse_subscription_path(path: str) -> Dict[str, str]:
+        """Parses a subscription path into its component segments."""
+        m = re.match(
+            r"^projects/(?P<project>.+?)/subscriptions/(?P<subscription>.+?)$", path
+        )
+        return m.groupdict() if m else {}
+
+    @staticmethod
+    def topic_path(project: str, topic: str,) -> str:
+        """Returns a fully-qualified topic string."""
+        return "projects/{project}/topics/{topic}".format(project=project, topic=topic,)
+
+    @staticmethod
+    def parse_topic_path(path: str) -> Dict[str, str]:
+        """Parses a topic path into its component segments."""
+        m = re.match(r"^projects/(?P<project>.+?)/topics/(?P<topic>.+?)$", path)
+        return m.groupdict() if m else {}
+
     @staticmethod
     def common_billing_account_path(billing_account: str,) -> str:
-        """Return a fully-qualified billing_account string."""
+        """Returns a fully-qualified billing_account string."""
         return "billingAccounts/{billing_account}".format(
             billing_account=billing_account,
         )
@@ -252,7 +278,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
     @staticmethod
     def common_folder_path(folder: str,) -> str:
-        """Return a fully-qualified folder string."""
+        """Returns a fully-qualified folder string."""
         return "folders/{folder}".format(folder=folder,)
 
     @staticmethod
@@ -263,7 +289,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
     @staticmethod
     def common_organization_path(organization: str,) -> str:
-        """Return a fully-qualified organization string."""
+        """Returns a fully-qualified organization string."""
         return "organizations/{organization}".format(organization=organization,)
 
     @staticmethod
@@ -274,7 +300,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
     @staticmethod
     def common_project_path(project: str,) -> str:
-        """Return a fully-qualified project string."""
+        """Returns a fully-qualified project string."""
         return "projects/{project}".format(project=project,)
 
     @staticmethod
@@ -285,7 +311,7 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
     @staticmethod
     def common_location_path(project: str, location: str,) -> str:
-        """Return a fully-qualified location string."""
+        """Returns a fully-qualified location string."""
         return "projects/{project}/locations/{location}".format(
             project=project, location=location,
         )
@@ -299,12 +325,12 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
     def __init__(
         self,
         *,
-        credentials: Optional[credentials.Credentials] = None,
+        credentials: Optional[ga_credentials.Credentials] = None,
         transport: Union[str, CloudBuildTransport, None] = None,
         client_options: Optional[client_options_lib.ClientOptions] = None,
         client_info: gapic_v1.client_info.ClientInfo = DEFAULT_CLIENT_INFO,
     ) -> None:
-        """Instantiate the cloud build client.
+        """Instantiates the cloud build client.
 
         Args:
             credentials (Optional[google.auth.credentials.Credentials]): The
@@ -359,9 +385,10 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 client_cert_source_func = client_options.client_cert_source
             else:
                 is_mtls = mtls.has_default_client_cert_source()
-                client_cert_source_func = (
-                    mtls.default_client_cert_source() if is_mtls else None
-                )
+                if is_mtls:
+                    client_cert_source_func = mtls.default_client_cert_source()
+                else:
+                    client_cert_source_func = None
 
         # Figure out which api endpoint to use.
         if client_options.api_endpoint is not None:
@@ -373,12 +400,14 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
             elif use_mtls_env == "always":
                 api_endpoint = self.DEFAULT_MTLS_ENDPOINT
             elif use_mtls_env == "auto":
-                api_endpoint = (
-                    self.DEFAULT_MTLS_ENDPOINT if is_mtls else self.DEFAULT_ENDPOINT
-                )
+                if is_mtls:
+                    api_endpoint = self.DEFAULT_MTLS_ENDPOINT
+                else:
+                    api_endpoint = self.DEFAULT_ENDPOINT
             else:
                 raise MutualTLSChannelError(
-                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted values: never, auto, always"
+                    "Unsupported GOOGLE_API_USE_MTLS_ENDPOINT value. Accepted "
+                    "values: never, auto, always"
                 )
 
         # Save or instantiate the transport.
@@ -393,8 +422,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 )
             if client_options.scopes:
                 raise ValueError(
-                    "When providing a transport instance, "
-                    "provide its scopes directly."
+                    "When providing a transport instance, provide its scopes "
+                    "directly."
                 )
             self._transport = transport
         else:
@@ -438,7 +467,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``build`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -492,10 +520,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.CreateBuildRequest):
             request = cloudbuild.CreateBuildRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
             if build is not None:
@@ -548,7 +574,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -598,10 +623,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.GetBuildRequest):
             request = cloudbuild.GetBuildRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
             if id is not None:
@@ -646,7 +669,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``filter`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -677,10 +699,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.ListBuildsRequest):
             request = cloudbuild.ListBuildsRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
             if filter is not None:
@@ -727,7 +747,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -777,10 +796,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.CancelBuildRequest):
             request = cloudbuild.CancelBuildRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
             if id is not None:
@@ -852,7 +869,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -906,10 +922,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.RetryBuildRequest):
             request = cloudbuild.RetryBuildRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
             if id is not None:
@@ -963,7 +977,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``trigger`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -993,10 +1006,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.CreateBuildTriggerRequest):
             request = cloudbuild.CreateBuildTriggerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
             if trigger is not None:
@@ -1044,7 +1055,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``trigger_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1074,10 +1084,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.GetBuildTriggerRequest):
             request = cloudbuild.GetBuildTriggerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
             if trigger_id is not None:
@@ -1117,7 +1125,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``project_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1148,10 +1155,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.ListBuildTriggersRequest):
             request = cloudbuild.ListBuildTriggersRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
 
@@ -1200,7 +1205,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``trigger_id`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1223,10 +1227,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.DeleteBuildTriggerRequest):
             request = cloudbuild.DeleteBuildTriggerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
             if trigger_id is not None:
@@ -1277,7 +1279,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``trigger`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1307,10 +1308,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.UpdateBuildTriggerRequest):
             request = cloudbuild.UpdateBuildTriggerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
             if trigger_id is not None:
@@ -1360,7 +1359,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 This corresponds to the ``source`` field
                 on the ``request`` instance; if ``request`` is provided, this
                 should not be set.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1414,10 +1412,8 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         # there are no flattened fields.
         if not isinstance(request, cloudbuild.RunBuildTriggerRequest):
             request = cloudbuild.RunBuildTriggerRequest(request)
-
             # If we have keyword arguments corresponding to fields on the
             # request, apply these.
-
             if project_id is not None:
                 request.project_id = project_id
             if trigger_id is not None:
@@ -1459,7 +1455,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 The request object. ReceiveTriggerWebhookRequest
                 [Experimental] is the request object accepted by the
                 ReceiveTriggerWebhook method.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1473,7 +1468,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a cloudbuild.ReceiveTriggerWebhookRequest.
         # There's no risk of modifying the input as we've already verified
@@ -1508,7 +1502,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
             request (google.cloud.devtools.cloudbuild_v1.types.CreateWorkerPoolRequest):
                 The request object. Request to create a new
                 `WorkerPool`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1532,7 +1525,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a cloudbuild.CreateWorkerPoolRequest.
         # There's no risk of modifying the input as we've already verified
@@ -1566,7 +1558,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
             request (google.cloud.devtools.cloudbuild_v1.types.GetWorkerPoolRequest):
                 The request object. Request to get a `WorkerPool` with
                 the specified name.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1590,7 +1581,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a cloudbuild.GetWorkerPoolRequest.
         # There's no risk of modifying the input as we've already verified
@@ -1623,7 +1613,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         Args:
             request (google.cloud.devtools.cloudbuild_v1.types.DeleteWorkerPoolRequest):
                 The request object. Request to delete a `WorkerPool`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1631,7 +1620,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 sent along with the request as metadata.
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a cloudbuild.DeleteWorkerPoolRequest.
         # There's no risk of modifying the input as we've already verified
@@ -1663,7 +1651,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         Args:
             request (google.cloud.devtools.cloudbuild_v1.types.UpdateWorkerPoolRequest):
                 The request object. Request to update a `WorkerPool`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1687,7 +1674,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
 
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a cloudbuild.UpdateWorkerPoolRequest.
         # There's no risk of modifying the input as we've already verified
@@ -1720,7 +1706,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
         Args:
             request (google.cloud.devtools.cloudbuild_v1.types.ListWorkerPoolsRequest):
                 The request object. Request to list `WorkerPools`.
-
             retry (google.api_core.retry.Retry): Designation of what errors, if any,
                 should be retried.
             timeout (float): The timeout for this request.
@@ -1732,7 +1717,6 @@ class CloudBuildClient(metaclass=CloudBuildClientMeta):
                 Response containing existing WorkerPools.
         """
         # Create or coerce a protobuf request object.
-
         # Minor optimization to avoid making a copy if the user passes
         # in a cloudbuild.ListWorkerPoolsRequest.
         # There's no risk of modifying the input as we've already verified
