@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,23 +13,21 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import warnings
-from typing import Callable, Dict, Optional, Sequence, Tuple
+from typing import Callable, Dict, Optional, Sequence, Tuple, Union
 
 from google.api_core import grpc_helpers  # type: ignore
 from google.api_core import operations_v1  # type: ignore
 from google.api_core import gapic_v1  # type: ignore
-from google import auth  # type: ignore
-from google.auth import credentials  # type: ignore
+import google.auth  # type: ignore
+from google.auth import credentials as ga_credentials  # type: ignore
 from google.auth.transport.grpc import SslCredentials  # type: ignore
 
 import grpc  # type: ignore
 
 from google.cloud.devtools.cloudbuild_v1.types import cloudbuild
-from google.longrunning import operations_pb2 as operations  # type: ignore
-from google.protobuf import empty_pb2 as empty  # type: ignore
-
+from google.longrunning import operations_pb2  # type: ignore
+from google.protobuf import empty_pb2  # type: ignore
 from .base import CloudBuildTransport, DEFAULT_CLIENT_INFO
 
 
@@ -60,7 +57,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
         self,
         *,
         host: str = "cloudbuild.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Sequence[str] = None,
         channel: grpc.Channel = None,
@@ -74,7 +71,8 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
         """Instantiate the transport.
 
         Args:
-            host (Optional[str]): The hostname to connect to.
+            host (Optional[str]):
+                 The hostname to connect to.
             credentials (Optional[google.auth.credentials.Credentials]): The
                 authorization credentials to attach to requests. These
                 credentials identify the application to the service; if none
@@ -185,7 +183,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     def create_channel(
         cls,
         host: str = "cloudbuild.googleapis.com",
-        credentials: credentials.Credentials = None,
+        credentials: ga_credentials.Credentials = None,
         credentials_file: str = None,
         scopes: Optional[Sequence[str]] = None,
         quota_project_id: Optional[str] = None,
@@ -216,13 +214,15 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             google.api_core.exceptions.DuplicateCredentialArgs: If both ``credentials``
               and ``credentials_file`` are passed.
         """
-        scopes = scopes or cls.AUTH_SCOPES
+
+        self_signed_jwt_kwargs = cls._get_self_signed_jwt_kwargs(host, scopes)
+
         return grpc_helpers.create_channel(
             host,
             credentials=credentials,
             credentials_file=credentials_file,
-            scopes=scopes,
             quota_project_id=quota_project_id,
+            **self_signed_jwt_kwargs,
             **kwargs,
         )
 
@@ -249,7 +249,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     @property
     def create_build(
         self,
-    ) -> Callable[[cloudbuild.CreateBuildRequest], operations.Operation]:
+    ) -> Callable[[cloudbuild.CreateBuildRequest], operations_pb2.Operation]:
         r"""Return a callable for the create build method over gRPC.
 
         Starts a build with the specified configuration.
@@ -272,7 +272,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             self._stubs["create_build"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/CreateBuild",
                 request_serializer=cloudbuild.CreateBuildRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["create_build"]
 
@@ -361,7 +361,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     @property
     def retry_build(
         self,
-    ) -> Callable[[cloudbuild.RetryBuildRequest], operations.Operation]:
+    ) -> Callable[[cloudbuild.RetryBuildRequest], operations_pb2.Operation]:
         r"""Return a callable for the retry build method over gRPC.
 
         Creates a new build based on the specified build.
@@ -409,7 +409,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             self._stubs["retry_build"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/RetryBuild",
                 request_serializer=cloudbuild.RetryBuildRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["retry_build"]
 
@@ -502,7 +502,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     @property
     def delete_build_trigger(
         self,
-    ) -> Callable[[cloudbuild.DeleteBuildTriggerRequest], empty.Empty]:
+    ) -> Callable[[cloudbuild.DeleteBuildTriggerRequest], empty_pb2.Empty]:
         r"""Return a callable for the delete build trigger method over gRPC.
 
         Deletes a ``BuildTrigger`` by its project ID and trigger ID.
@@ -523,7 +523,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             self._stubs["delete_build_trigger"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/DeleteBuildTrigger",
                 request_serializer=cloudbuild.DeleteBuildTriggerRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_build_trigger"]
 
@@ -558,7 +558,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     @property
     def run_build_trigger(
         self,
-    ) -> Callable[[cloudbuild.RunBuildTriggerRequest], operations.Operation]:
+    ) -> Callable[[cloudbuild.RunBuildTriggerRequest], operations_pb2.Operation]:
         r"""Return a callable for the run build trigger method over gRPC.
 
         Runs a ``BuildTrigger`` at a particular source revision.
@@ -577,7 +577,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             self._stubs["run_build_trigger"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/RunBuildTrigger",
                 request_serializer=cloudbuild.RunBuildTriggerRequest.serialize,
-                response_deserializer=operations.Operation.FromString,
+                response_deserializer=operations_pb2.Operation.FromString,
             )
         return self._stubs["run_build_trigger"]
 
@@ -671,7 +671,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
     @property
     def delete_worker_pool(
         self,
-    ) -> Callable[[cloudbuild.DeleteWorkerPoolRequest], empty.Empty]:
+    ) -> Callable[[cloudbuild.DeleteWorkerPoolRequest], empty_pb2.Empty]:
         r"""Return a callable for the delete worker pool method over gRPC.
 
         Deletes a ``WorkerPool`` by its project ID and WorkerPool name.
@@ -692,7 +692,7 @@ class CloudBuildGrpcTransport(CloudBuildTransport):
             self._stubs["delete_worker_pool"] = self.grpc_channel.unary_unary(
                 "/google.devtools.cloudbuild.v1.CloudBuild/DeleteWorkerPool",
                 request_serializer=cloudbuild.DeleteWorkerPoolRequest.serialize,
-                response_deserializer=empty.Empty.FromString,
+                response_deserializer=empty_pb2.Empty.FromString,
             )
         return self._stubs["delete_worker_pool"]
 
