@@ -1,5 +1,4 @@
 # -*- coding: utf-8 -*-
-
 # Copyright 2020 Google LLC
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
@@ -14,13 +13,11 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 #
-
 import proto  # type: ignore
 
-
-from google.api import httpbody_pb2 as httpbody  # type: ignore
-from google.protobuf import duration_pb2 as duration  # type: ignore
-from google.protobuf import timestamp_pb2 as timestamp  # type: ignore
+from google.api import httpbody_pb2  # type: ignore
+from google.protobuf import duration_pb2  # type: ignore
+from google.protobuf import timestamp_pb2  # type: ignore
 
 
 __protobuf__ = proto.module(
@@ -30,6 +27,7 @@ __protobuf__ = proto.module(
         "RunBuildTriggerRequest",
         "StorageSource",
         "RepoSource",
+        "StorageSourceManifest",
         "Source",
         "BuiltImage",
         "BuildStep",
@@ -54,6 +52,7 @@ __protobuf__ = proto.module(
         "CancelBuildRequest",
         "BuildTrigger",
         "GitHubEventsConfig",
+        "PubsubConfig",
         "PullRequestFilter",
         "PushFilter",
         "CreateBuildTriggerRequest",
@@ -80,7 +79,6 @@ __protobuf__ = proto.module(
 
 class RetryBuildRequest(proto.Message):
     r"""Specifies a build to retry.
-
     Attributes:
         name (str):
             The name of the ``Build`` to retry. Format:
@@ -91,16 +89,13 @@ class RetryBuildRequest(proto.Message):
             Required. Build ID of the original build.
     """
 
-    name = proto.Field(proto.STRING, number=3)
-
-    project_id = proto.Field(proto.STRING, number=1)
-
-    id = proto.Field(proto.STRING, number=2)
+    name = proto.Field(proto.STRING, number=3,)
+    project_id = proto.Field(proto.STRING, number=1,)
+    id = proto.Field(proto.STRING, number=2,)
 
 
 class RunBuildTriggerRequest(proto.Message):
     r"""Specifies a build trigger to run and the source to use.
-
     Attributes:
         project_id (str):
             Required. ID of the project.
@@ -110,10 +105,8 @@ class RunBuildTriggerRequest(proto.Message):
             Source to build against this trigger.
     """
 
-    project_id = proto.Field(proto.STRING, number=1)
-
-    trigger_id = proto.Field(proto.STRING, number=2)
-
+    project_id = proto.Field(proto.STRING, number=1,)
+    trigger_id = proto.Field(proto.STRING, number=2,)
     source = proto.Field(proto.MESSAGE, number=3, message="RepoSource",)
 
 
@@ -137,16 +130,13 @@ class StorageSource(proto.Message):
             generation will be used.
     """
 
-    bucket = proto.Field(proto.STRING, number=1)
-
-    object_ = proto.Field(proto.STRING, number=2)
-
-    generation = proto.Field(proto.INT64, number=3)
+    bucket = proto.Field(proto.STRING, number=1,)
+    object_ = proto.Field(proto.STRING, number=2,)
+    generation = proto.Field(proto.INT64, number=3,)
 
 
 class RepoSource(proto.Message):
     r"""Location of the source in a Google Cloud Source Repository.
-
     Attributes:
         project_id (str):
             ID of the project that owns the Cloud Source
@@ -181,26 +171,42 @@ class RepoSource(proto.Message):
             Should only be used with RunBuildTrigger
     """
 
-    project_id = proto.Field(proto.STRING, number=1)
+    project_id = proto.Field(proto.STRING, number=1,)
+    repo_name = proto.Field(proto.STRING, number=2,)
+    branch_name = proto.Field(proto.STRING, number=3, oneof="revision",)
+    tag_name = proto.Field(proto.STRING, number=4, oneof="revision",)
+    commit_sha = proto.Field(proto.STRING, number=5, oneof="revision",)
+    dir_ = proto.Field(proto.STRING, number=7,)
+    invert_regex = proto.Field(proto.BOOL, number=8,)
+    substitutions = proto.MapField(proto.STRING, proto.STRING, number=9,)
 
-    repo_name = proto.Field(proto.STRING, number=2)
 
-    branch_name = proto.Field(proto.STRING, number=3, oneof="revision")
+class StorageSourceManifest(proto.Message):
+    r"""Location of the source manifest in Google Cloud Storage.
+    This feature is in Preview.
 
-    tag_name = proto.Field(proto.STRING, number=4, oneof="revision")
+    Attributes:
+        bucket (str):
+            Google Cloud Storage bucket containing the source manifest
+            (see `Bucket Name
+            Requirements <https://cloud.google.com/storage/docs/bucket-naming#requirements>`__).
+        object_ (str):
+            Google Cloud Storage object containing the
+            source manifest.
+            This object must be a JSON file.
+        generation (int):
+            Google Cloud Storage generation for the
+            object. If the generation is omitted, the latest
+            generation will be used.
+    """
 
-    commit_sha = proto.Field(proto.STRING, number=5, oneof="revision")
-
-    dir_ = proto.Field(proto.STRING, number=7)
-
-    invert_regex = proto.Field(proto.BOOL, number=8)
-
-    substitutions = proto.MapField(proto.STRING, proto.STRING, number=9)
+    bucket = proto.Field(proto.STRING, number=1,)
+    object_ = proto.Field(proto.STRING, number=2,)
+    generation = proto.Field(proto.INT64, number=3,)
 
 
 class Source(proto.Message):
     r"""Location of the source in a supported storage service.
-
     Attributes:
         storage_source (google.cloud.devtools.cloudbuild_v1.types.StorageSource):
             If provided, get the source from this
@@ -208,20 +214,25 @@ class Source(proto.Message):
         repo_source (google.cloud.devtools.cloudbuild_v1.types.RepoSource):
             If provided, get the source from this
             location in a Cloud Source Repository.
+        storage_source_manifest (google.cloud.devtools.cloudbuild_v1.types.StorageSourceManifest):
+            If provided, get the source from this
+            manifest in Google Cloud Storage. This feature
+            is in Preview.
     """
 
     storage_source = proto.Field(
         proto.MESSAGE, number=2, oneof="source", message="StorageSource",
     )
-
     repo_source = proto.Field(
         proto.MESSAGE, number=3, oneof="source", message="RepoSource",
     )
+    storage_source_manifest = proto.Field(
+        proto.MESSAGE, number=8, oneof="source", message="StorageSourceManifest",
+    )
 
 
 class BuiltImage(proto.Message):
     r"""An image built by the pipeline.
-
     Attributes:
         name (str):
             Name used to push the container image to Google Container
@@ -233,16 +244,13 @@ class BuiltImage(proto.Message):
             pushing the specified image.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    digest = proto.Field(proto.STRING, number=3)
-
+    name = proto.Field(proto.STRING, number=1,)
+    digest = proto.Field(proto.STRING, number=3,)
     push_timing = proto.Field(proto.MESSAGE, number=4, message="TimeSpan",)
 
 
 class BuildStep(proto.Message):
     r"""A step in the build pipeline.
-
     Attributes:
         name (str):
             Required. The name of the container image that will run this
@@ -336,30 +344,18 @@ class BuildStep(proto.Message):
             real-time as the build progresses.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    env = proto.RepeatedField(proto.STRING, number=2)
-
-    args = proto.RepeatedField(proto.STRING, number=3)
-
-    dir_ = proto.Field(proto.STRING, number=4)
-
-    id = proto.Field(proto.STRING, number=5)
-
-    wait_for = proto.RepeatedField(proto.STRING, number=6)
-
-    entrypoint = proto.Field(proto.STRING, number=7)
-
-    secret_env = proto.RepeatedField(proto.STRING, number=8)
-
+    name = proto.Field(proto.STRING, number=1,)
+    env = proto.RepeatedField(proto.STRING, number=2,)
+    args = proto.RepeatedField(proto.STRING, number=3,)
+    dir_ = proto.Field(proto.STRING, number=4,)
+    id = proto.Field(proto.STRING, number=5,)
+    wait_for = proto.RepeatedField(proto.STRING, number=6,)
+    entrypoint = proto.Field(proto.STRING, number=7,)
+    secret_env = proto.RepeatedField(proto.STRING, number=8,)
     volumes = proto.RepeatedField(proto.MESSAGE, number=9, message="Volume",)
-
     timing = proto.Field(proto.MESSAGE, number=10, message="TimeSpan",)
-
     pull_timing = proto.Field(proto.MESSAGE, number=13, message="TimeSpan",)
-
-    timeout = proto.Field(proto.MESSAGE, number=11, message=duration.Duration,)
-
+    timeout = proto.Field(proto.MESSAGE, number=11, message=duration_pb2.Duration,)
     status = proto.Field(proto.ENUM, number=12, enum="Build.Status",)
 
 
@@ -382,14 +378,12 @@ class Volume(proto.Message):
             with certain reserved volume paths.
     """
 
-    name = proto.Field(proto.STRING, number=1)
-
-    path = proto.Field(proto.STRING, number=2)
+    name = proto.Field(proto.STRING, number=1,)
+    path = proto.Field(proto.STRING, number=2,)
 
 
 class Results(proto.Message):
     r"""Artifacts created by the build pipeline.
-
     Attributes:
         images (Sequence[google.cloud.devtools.cloudbuild_v1.types.BuiltImage]):
             Container images that were built as a part of
@@ -417,15 +411,10 @@ class Results(proto.Message):
     """
 
     images = proto.RepeatedField(proto.MESSAGE, number=2, message="BuiltImage",)
-
-    build_step_images = proto.RepeatedField(proto.STRING, number=3)
-
-    artifact_manifest = proto.Field(proto.STRING, number=4)
-
-    num_artifacts = proto.Field(proto.INT64, number=5)
-
-    build_step_outputs = proto.RepeatedField(proto.BYTES, number=6)
-
+    build_step_images = proto.RepeatedField(proto.STRING, number=3,)
+    artifact_manifest = proto.Field(proto.STRING, number=4,)
+    num_artifacts = proto.Field(proto.INT64, number=5,)
+    build_step_outputs = proto.RepeatedField(proto.BYTES, number=6,)
     artifact_timing = proto.Field(proto.MESSAGE, number=7, message="TimeSpan",)
 
 
@@ -442,8 +431,7 @@ class ArtifactResult(proto.Message):
             The file hash of the artifact.
     """
 
-    location = proto.Field(proto.STRING, number=1)
-
+    location = proto.Field(proto.STRING, number=1,)
     file_hash = proto.RepeatedField(proto.MESSAGE, number=2, message="FileHashes",)
 
 
@@ -594,58 +582,33 @@ class Build(proto.Message):
         CANCELLED = 7
         EXPIRED = 9
 
-    name = proto.Field(proto.STRING, number=45)
-
-    id = proto.Field(proto.STRING, number=1)
-
-    project_id = proto.Field(proto.STRING, number=16)
-
+    name = proto.Field(proto.STRING, number=45,)
+    id = proto.Field(proto.STRING, number=1,)
+    project_id = proto.Field(proto.STRING, number=16,)
     status = proto.Field(proto.ENUM, number=2, enum=Status,)
-
-    status_detail = proto.Field(proto.STRING, number=24)
-
+    status_detail = proto.Field(proto.STRING, number=24,)
     source = proto.Field(proto.MESSAGE, number=3, message="Source",)
-
     steps = proto.RepeatedField(proto.MESSAGE, number=11, message="BuildStep",)
-
     results = proto.Field(proto.MESSAGE, number=10, message="Results",)
-
-    create_time = proto.Field(proto.MESSAGE, number=6, message=timestamp.Timestamp,)
-
-    start_time = proto.Field(proto.MESSAGE, number=7, message=timestamp.Timestamp,)
-
-    finish_time = proto.Field(proto.MESSAGE, number=8, message=timestamp.Timestamp,)
-
-    timeout = proto.Field(proto.MESSAGE, number=12, message=duration.Duration,)
-
-    images = proto.RepeatedField(proto.STRING, number=13)
-
-    queue_ttl = proto.Field(proto.MESSAGE, number=40, message=duration.Duration,)
-
+    create_time = proto.Field(proto.MESSAGE, number=6, message=timestamp_pb2.Timestamp,)
+    start_time = proto.Field(proto.MESSAGE, number=7, message=timestamp_pb2.Timestamp,)
+    finish_time = proto.Field(proto.MESSAGE, number=8, message=timestamp_pb2.Timestamp,)
+    timeout = proto.Field(proto.MESSAGE, number=12, message=duration_pb2.Duration,)
+    images = proto.RepeatedField(proto.STRING, number=13,)
+    queue_ttl = proto.Field(proto.MESSAGE, number=40, message=duration_pb2.Duration,)
     artifacts = proto.Field(proto.MESSAGE, number=37, message="Artifacts",)
-
-    logs_bucket = proto.Field(proto.STRING, number=19)
-
+    logs_bucket = proto.Field(proto.STRING, number=19,)
     source_provenance = proto.Field(
         proto.MESSAGE, number=21, message="SourceProvenance",
     )
-
-    build_trigger_id = proto.Field(proto.STRING, number=22)
-
+    build_trigger_id = proto.Field(proto.STRING, number=22,)
     options = proto.Field(proto.MESSAGE, number=23, message="BuildOptions",)
-
-    log_url = proto.Field(proto.STRING, number=25)
-
-    substitutions = proto.MapField(proto.STRING, proto.STRING, number=29)
-
-    tags = proto.RepeatedField(proto.STRING, number=31)
-
+    log_url = proto.Field(proto.STRING, number=25,)
+    substitutions = proto.MapField(proto.STRING, proto.STRING, number=29,)
+    tags = proto.RepeatedField(proto.STRING, number=31,)
     secrets = proto.RepeatedField(proto.MESSAGE, number=32, message="Secret",)
-
     timing = proto.MapField(proto.STRING, proto.MESSAGE, number=33, message="TimeSpan",)
-
-    service_account = proto.Field(proto.STRING, number=42)
-
+    service_account = proto.Field(proto.STRING, number=42,)
     available_secrets = proto.Field(proto.MESSAGE, number=47, message="Secrets",)
 
 
@@ -702,20 +665,16 @@ class Artifacts(proto.Message):
                 pushing all artifact objects.
         """
 
-        location = proto.Field(proto.STRING, number=1)
-
-        paths = proto.RepeatedField(proto.STRING, number=2)
-
+        location = proto.Field(proto.STRING, number=1,)
+        paths = proto.RepeatedField(proto.STRING, number=2,)
         timing = proto.Field(proto.MESSAGE, number=3, message="TimeSpan",)
 
-    images = proto.RepeatedField(proto.STRING, number=1)
-
+    images = proto.RepeatedField(proto.STRING, number=1,)
     objects = proto.Field(proto.MESSAGE, number=2, message=ArtifactObjects,)
 
 
 class TimeSpan(proto.Message):
     r"""Start and end times for a build execution phase.
-
     Attributes:
         start_time (google.protobuf.timestamp_pb2.Timestamp):
             Start of time span.
@@ -723,14 +682,12 @@ class TimeSpan(proto.Message):
             End of time span.
     """
 
-    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp.Timestamp,)
-
-    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp.Timestamp,)
+    start_time = proto.Field(proto.MESSAGE, number=1, message=timestamp_pb2.Timestamp,)
+    end_time = proto.Field(proto.MESSAGE, number=2, message=timestamp_pb2.Timestamp,)
 
 
 class BuildOperationMetadata(proto.Message):
     r"""Metadata for build operations.
-
     Attributes:
         build (google.cloud.devtools.cloudbuild_v1.types.Build):
             The build that the operation is tracking.
@@ -750,6 +707,10 @@ class SourceProvenance(proto.Message):
         resolved_repo_source (google.cloud.devtools.cloudbuild_v1.types.RepoSource):
             A copy of the build's ``source.repo_source``, if exists,
             with any revisions resolved.
+        resolved_storage_source_manifest (google.cloud.devtools.cloudbuild_v1.types.StorageSourceManifest):
+            A copy of the build's ``source.storage_source_manifest``, if
+            exists, with any revisions resolved. This feature is in
+            Preview.
         file_hashes (Sequence[google.cloud.devtools.cloudbuild_v1.types.SourceProvenance.FileHashesEntry]):
             Output only. Hash(es) of the build source, which can be used
             to verify that the original source integrity was maintained
@@ -768,9 +729,10 @@ class SourceProvenance(proto.Message):
     resolved_storage_source = proto.Field(
         proto.MESSAGE, number=3, message="StorageSource",
     )
-
     resolved_repo_source = proto.Field(proto.MESSAGE, number=6, message="RepoSource",)
-
+    resolved_storage_source_manifest = proto.Field(
+        proto.MESSAGE, number=9, message="StorageSourceManifest",
+    )
     file_hashes = proto.MapField(
         proto.STRING, proto.MESSAGE, number=4, message="FileHashes",
     )
@@ -791,7 +753,6 @@ class FileHashes(proto.Message):
 
 class Hash(proto.Message):
     r"""Container message for hash values.
-
     Attributes:
         type_ (google.cloud.devtools.cloudbuild_v1.types.Hash.HashType):
             The type of hash that was performed.
@@ -806,13 +767,11 @@ class Hash(proto.Message):
         MD5 = 2
 
     type_ = proto.Field(proto.ENUM, number=1, enum=HashType,)
-
-    value = proto.Field(proto.BYTES, number=2)
+    value = proto.Field(proto.BYTES, number=2,)
 
 
 class Secrets(proto.Message):
     r"""Secrets and secret environment variables.
-
     Attributes:
         secret_manager (Sequence[google.cloud.devtools.cloudbuild_v1.types.SecretManagerSecret]):
             Secrets in Secret Manager and associated
@@ -825,7 +784,6 @@ class Secrets(proto.Message):
     secret_manager = proto.RepeatedField(
         proto.MESSAGE, number=1, message="SecretManagerSecret",
     )
-
     inline = proto.RepeatedField(proto.MESSAGE, number=2, message="InlineSecret",)
 
 
@@ -849,9 +807,8 @@ class InlineSecret(proto.Message):
             secret values across all of a build's secrets.
     """
 
-    kms_key_name = proto.Field(proto.STRING, number=1)
-
-    env_map = proto.MapField(proto.STRING, proto.BYTES, number=2)
+    kms_key_name = proto.Field(proto.STRING, number=1,)
+    env_map = proto.MapField(proto.STRING, proto.BYTES, number=2,)
 
 
 class SecretManagerSecret(proto.Message):
@@ -869,9 +826,8 @@ class SecretManagerSecret(proto.Message):
             be used by at least one build step.
     """
 
-    version_name = proto.Field(proto.STRING, number=1)
-
-    env = proto.Field(proto.STRING, number=2)
+    version_name = proto.Field(proto.STRING, number=1,)
+    env = proto.Field(proto.STRING, number=2,)
 
 
 class Secret(proto.Message):
@@ -895,14 +851,12 @@ class Secret(proto.Message):
             secret values across all of a build's secrets.
     """
 
-    kms_key_name = proto.Field(proto.STRING, number=1)
-
-    secret_env = proto.MapField(proto.STRING, proto.BYTES, number=3)
+    kms_key_name = proto.Field(proto.STRING, number=1,)
+    secret_env = proto.MapField(proto.STRING, proto.BYTES, number=3,)
 
 
 class CreateBuildRequest(proto.Message):
     r"""Request to create a new build.
-
     Attributes:
         parent (str):
             The parent resource where this build will be created.
@@ -913,16 +867,13 @@ class CreateBuildRequest(proto.Message):
             Required. Build resource to create.
     """
 
-    parent = proto.Field(proto.STRING, number=4)
-
-    project_id = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=4,)
+    project_id = proto.Field(proto.STRING, number=1,)
     build = proto.Field(proto.MESSAGE, number=2, message="Build",)
 
 
 class GetBuildRequest(proto.Message):
     r"""Request to get a build.
-
     Attributes:
         name (str):
             The name of the ``Build`` to retrieve. Format:
@@ -933,16 +884,13 @@ class GetBuildRequest(proto.Message):
             Required. ID of the build.
     """
 
-    name = proto.Field(proto.STRING, number=4)
-
-    project_id = proto.Field(proto.STRING, number=1)
-
-    id = proto.Field(proto.STRING, number=2)
+    name = proto.Field(proto.STRING, number=4,)
+    project_id = proto.Field(proto.STRING, number=1,)
+    id = proto.Field(proto.STRING, number=2,)
 
 
 class ListBuildsRequest(proto.Message):
     r"""Request to list builds.
-
     Attributes:
         parent (str):
             The parent of the collection of ``Builds``. Format:
@@ -966,20 +914,15 @@ class ListBuildsRequest(proto.Message):
             The raw filter text to constrain the results.
     """
 
-    parent = proto.Field(proto.STRING, number=9)
-
-    project_id = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
-
-    filter = proto.Field(proto.STRING, number=8)
+    parent = proto.Field(proto.STRING, number=9,)
+    project_id = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
+    filter = proto.Field(proto.STRING, number=8,)
 
 
 class ListBuildsResponse(proto.Message):
     r"""Response including listed builds.
-
     Attributes:
         builds (Sequence[google.cloud.devtools.cloudbuild_v1.types.Build]):
             Builds will be sorted by ``create_time``, descending.
@@ -994,13 +937,11 @@ class ListBuildsResponse(proto.Message):
         return self
 
     builds = proto.RepeatedField(proto.MESSAGE, number=1, message="Build",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class CancelBuildRequest(proto.Message):
     r"""Request to cancel an ongoing build.
-
     Attributes:
         name (str):
             The name of the ``Build`` to cancel. Format:
@@ -1011,11 +952,9 @@ class CancelBuildRequest(proto.Message):
             Required. ID of the build.
     """
 
-    name = proto.Field(proto.STRING, number=4)
-
-    project_id = proto.Field(proto.STRING, number=1)
-
-    id = proto.Field(proto.STRING, number=2)
+    name = proto.Field(proto.STRING, number=4,)
+    project_id = proto.Field(proto.STRING, number=1,)
+    id = proto.Field(proto.STRING, number=2,)
 
 
 class BuildTrigger(proto.Message):
@@ -1052,6 +991,10 @@ class BuildTrigger(proto.Message):
             that creates a build whenever a GitHub event is received.
 
             Mutually exclusive with ``trigger_template``.
+        pubsub_config (google.cloud.devtools.cloudbuild_v1.types.PubsubConfig):
+            Optional. PubsubConfig describes the
+            configuration of a trigger that creates a build
+            whenever a Pub/Sub message is published.
         build (google.cloud.devtools.cloudbuild_v1.types.Build):
             Contents of the build template.
         filename (str):
@@ -1088,35 +1031,28 @@ class BuildTrigger(proto.Message):
             ignored_files filter and included_files is not empty, then
             we make sure that at least one of those files matches a
             included_files glob. If not, then we do not trigger a build.
+        filter (str):
+            Optional. A Common Expression Language
+            string.
     """
 
-    id = proto.Field(proto.STRING, number=1)
-
-    description = proto.Field(proto.STRING, number=10)
-
-    name = proto.Field(proto.STRING, number=21)
-
-    tags = proto.RepeatedField(proto.STRING, number=19)
-
+    id = proto.Field(proto.STRING, number=1,)
+    description = proto.Field(proto.STRING, number=10,)
+    name = proto.Field(proto.STRING, number=21,)
+    tags = proto.RepeatedField(proto.STRING, number=19,)
     trigger_template = proto.Field(proto.MESSAGE, number=7, message="RepoSource",)
-
     github = proto.Field(proto.MESSAGE, number=13, message="GitHubEventsConfig",)
-
+    pubsub_config = proto.Field(proto.MESSAGE, number=29, message="PubsubConfig",)
     build = proto.Field(
         proto.MESSAGE, number=4, oneof="build_template", message="Build",
     )
-
-    filename = proto.Field(proto.STRING, number=8, oneof="build_template")
-
-    create_time = proto.Field(proto.MESSAGE, number=5, message=timestamp.Timestamp,)
-
-    disabled = proto.Field(proto.BOOL, number=9)
-
-    substitutions = proto.MapField(proto.STRING, proto.STRING, number=11)
-
-    ignored_files = proto.RepeatedField(proto.STRING, number=15)
-
-    included_files = proto.RepeatedField(proto.STRING, number=16)
+    filename = proto.Field(proto.STRING, number=8, oneof="build_template",)
+    create_time = proto.Field(proto.MESSAGE, number=5, message=timestamp_pb2.Timestamp,)
+    disabled = proto.Field(proto.BOOL, number=9,)
+    substitutions = proto.MapField(proto.STRING, proto.STRING, number=11,)
+    ignored_files = proto.RepeatedField(proto.STRING, number=15,)
+    included_files = proto.RepeatedField(proto.STRING, number=16,)
+    filter = proto.Field(proto.STRING, number=30,)
 
 
 class GitHubEventsConfig(proto.Message):
@@ -1145,19 +1081,52 @@ class GitHubEventsConfig(proto.Message):
             branches, tags.
     """
 
-    installation_id = proto.Field(proto.INT64, number=1)
-
-    owner = proto.Field(proto.STRING, number=6)
-
-    name = proto.Field(proto.STRING, number=7)
-
+    installation_id = proto.Field(proto.INT64, number=1,)
+    owner = proto.Field(proto.STRING, number=6,)
+    name = proto.Field(proto.STRING, number=7,)
     pull_request = proto.Field(
         proto.MESSAGE, number=4, oneof="event", message="PullRequestFilter",
     )
-
     push = proto.Field(proto.MESSAGE, number=5, oneof="event", message="PushFilter",)
 
 
+class PubsubConfig(proto.Message):
+    r"""PubsubConfig describes the configuration of a trigger that
+    creates a build whenever a Pub/Sub message is published.
+
+    Attributes:
+        subscription (str):
+            Output only. Name of the subscription. Format is
+            ``projects/{project}/subscriptions/{subscription}``.
+        topic (str):
+            The name of the topic from which this subscription is
+            receiving messages. Format is
+            ``projects/{project}/topics/{topic}``.
+        service_account_email (str):
+            Service account that will make the push
+            request.
+        state (google.cloud.devtools.cloudbuild_v1.types.PubsubConfig.State):
+            Potential issues with the underlying Pub/Sub
+            subscription configuration. Only populated on
+            get requests.
+    """
+
+    class State(proto.Enum):
+        r"""Enumerates potential issues with the underlying Pub/Sub
+        subscription configuration.
+        """
+        STATE_UNSPECIFIED = 0
+        OK = 1
+        SUBSCRIPTION_DELETED = 2
+        TOPIC_DELETED = 3
+        SUBSCRIPTION_MISCONFIGURED = 4
+
+    subscription = proto.Field(proto.STRING, number=1,)
+    topic = proto.Field(proto.STRING, number=2,)
+    service_account_email = proto.Field(proto.STRING, number=3,)
+    state = proto.Field(proto.ENUM, number=4, enum=State,)
+
+
 class PullRequestFilter(proto.Message):
     r"""PullRequestFilter contains filter properties for matching
     GitHub Pull Requests.
@@ -1182,11 +1151,9 @@ class PullRequestFilter(proto.Message):
         COMMENTS_ENABLED = 1
         COMMENTS_ENABLED_FOR_EXTERNAL_CONTRIBUTORS_ONLY = 2
 
-    branch = proto.Field(proto.STRING, number=2, oneof="git_ref")
-
+    branch = proto.Field(proto.STRING, number=2, oneof="git_ref",)
     comment_control = proto.Field(proto.ENUM, number=5, enum=CommentControl,)
-
-    invert_regex = proto.Field(proto.BOOL, number=6)
+    invert_regex = proto.Field(proto.BOOL, number=6,)
 
 
 class PushFilter(proto.Message):
@@ -1209,16 +1176,13 @@ class PushFilter(proto.Message):
             NOT match the git_ref regex.
     """
 
-    branch = proto.Field(proto.STRING, number=2, oneof="git_ref")
-
-    tag = proto.Field(proto.STRING, number=3, oneof="git_ref")
-
-    invert_regex = proto.Field(proto.BOOL, number=4)
+    branch = proto.Field(proto.STRING, number=2, oneof="git_ref",)
+    tag = proto.Field(proto.STRING, number=3, oneof="git_ref",)
+    invert_regex = proto.Field(proto.BOOL, number=4,)
 
 
 class CreateBuildTriggerRequest(proto.Message):
     r"""Request to create a new ``BuildTrigger``.
-
     Attributes:
         project_id (str):
             Required. ID of the project for which to
@@ -1227,14 +1191,12 @@ class CreateBuildTriggerRequest(proto.Message):
             Required. ``BuildTrigger`` to create.
     """
 
-    project_id = proto.Field(proto.STRING, number=1)
-
+    project_id = proto.Field(proto.STRING, number=1,)
     trigger = proto.Field(proto.MESSAGE, number=2, message="BuildTrigger",)
 
 
 class GetBuildTriggerRequest(proto.Message):
     r"""Returns the ``BuildTrigger`` with the specified ID.
-
     Attributes:
         project_id (str):
             Required. ID of the project that owns the
@@ -1244,14 +1206,12 @@ class GetBuildTriggerRequest(proto.Message):
             ``BuildTrigger`` to get.
     """
 
-    project_id = proto.Field(proto.STRING, number=1)
-
-    trigger_id = proto.Field(proto.STRING, number=2)
+    project_id = proto.Field(proto.STRING, number=1,)
+    trigger_id = proto.Field(proto.STRING, number=2,)
 
 
 class ListBuildTriggersRequest(proto.Message):
     r"""Request to list existing ``BuildTriggers``.
-
     Attributes:
         project_id (str):
             Required. ID of the project for which to list
@@ -1263,16 +1223,13 @@ class ListBuildTriggersRequest(proto.Message):
             in the list.
     """
 
-    project_id = proto.Field(proto.STRING, number=1)
-
-    page_size = proto.Field(proto.INT32, number=2)
-
-    page_token = proto.Field(proto.STRING, number=3)
+    project_id = proto.Field(proto.STRING, number=1,)
+    page_size = proto.Field(proto.INT32, number=2,)
+    page_token = proto.Field(proto.STRING, number=3,)
 
 
 class ListBuildTriggersResponse(proto.Message):
     r"""Response containing existing ``BuildTriggers``.
-
     Attributes:
         triggers (Sequence[google.cloud.devtools.cloudbuild_v1.types.BuildTrigger]):
             ``BuildTriggers`` for the project, sorted by ``create_time``
@@ -1286,13 +1243,11 @@ class ListBuildTriggersResponse(proto.Message):
         return self
 
     triggers = proto.RepeatedField(proto.MESSAGE, number=1, message="BuildTrigger",)
-
-    next_page_token = proto.Field(proto.STRING, number=2)
+    next_page_token = proto.Field(proto.STRING, number=2,)
 
 
 class DeleteBuildTriggerRequest(proto.Message):
     r"""Request to delete a ``BuildTrigger``.
-
     Attributes:
         project_id (str):
             Required. ID of the project that owns the
@@ -1301,14 +1256,12 @@ class DeleteBuildTriggerRequest(proto.Message):
             Required. ID of the ``BuildTrigger`` to delete.
     """
 
-    project_id = proto.Field(proto.STRING, number=1)
-
-    trigger_id = proto.Field(proto.STRING, number=2)
+    project_id = proto.Field(proto.STRING, number=1,)
+    trigger_id = proto.Field(proto.STRING, number=2,)
 
 
 class UpdateBuildTriggerRequest(proto.Message):
     r"""Request to update an existing ``BuildTrigger``.
-
     Attributes:
         project_id (str):
             Required. ID of the project that owns the
@@ -1319,16 +1272,13 @@ class UpdateBuildTriggerRequest(proto.Message):
             Required. ``BuildTrigger`` to update.
     """
 
-    project_id = proto.Field(proto.STRING, number=1)
-
-    trigger_id = proto.Field(proto.STRING, number=2)
-
+    project_id = proto.Field(proto.STRING, number=1,)
+    trigger_id = proto.Field(proto.STRING, number=2,)
     trigger = proto.Field(proto.MESSAGE, number=3, message="BuildTrigger",)
 
 
 class BuildOptions(proto.Message):
     r"""Optional arguments to enable specific features of builds.
-
     Attributes:
         source_provenance_hash (Sequence[google.cloud.devtools.cloudbuild_v1.types.Hash.HashType]):
             Requested hash for SourceProvenance.
@@ -1444,27 +1394,16 @@ class BuildOptions(proto.Message):
     source_provenance_hash = proto.RepeatedField(
         proto.ENUM, number=1, enum="Hash.HashType",
     )
-
     requested_verify_option = proto.Field(proto.ENUM, number=2, enum=VerifyOption,)
-
     machine_type = proto.Field(proto.ENUM, number=3, enum=MachineType,)
-
-    disk_size_gb = proto.Field(proto.INT64, number=6)
-
+    disk_size_gb = proto.Field(proto.INT64, number=6,)
     substitution_option = proto.Field(proto.ENUM, number=4, enum=SubstitutionOption,)
-
-    dynamic_substitutions = proto.Field(proto.BOOL, number=17)
-
+    dynamic_substitutions = proto.Field(proto.BOOL, number=17,)
     log_streaming_option = proto.Field(proto.ENUM, number=5, enum=LogStreamingOption,)
-
-    worker_pool = proto.Field(proto.STRING, number=7)
-
+    worker_pool = proto.Field(proto.STRING, number=7,)
     logging = proto.Field(proto.ENUM, number=11, enum=LoggingMode,)
-
-    env = proto.RepeatedField(proto.STRING, number=12)
-
-    secret_env = proto.RepeatedField(proto.STRING, number=13)
-
+    env = proto.RepeatedField(proto.STRING, number=12,)
+    secret_env = proto.RepeatedField(proto.STRING, number=13,)
     volumes = proto.RepeatedField(proto.MESSAGE, number=14, message="Volume",)
 
 
@@ -1485,19 +1424,16 @@ class ReceiveTriggerWebhookRequest(proto.Message):
             OAuth token isn't provided.
     """
 
-    body = proto.Field(proto.MESSAGE, number=1, message=httpbody.HttpBody,)
-
-    project_id = proto.Field(proto.STRING, number=2)
-
-    trigger = proto.Field(proto.STRING, number=3)
-
-    secret = proto.Field(proto.STRING, number=4)
+    body = proto.Field(proto.MESSAGE, number=1, message=httpbody_pb2.HttpBody,)
+    project_id = proto.Field(proto.STRING, number=2,)
+    trigger = proto.Field(proto.STRING, number=3,)
+    secret = proto.Field(proto.STRING, number=4,)
 
 
 class ReceiveTriggerWebhookResponse(proto.Message):
     r"""ReceiveTriggerWebhookResponse [Experimental] is the response object
     for the ReceiveTriggerWebhook method.
-    """
+        """
 
 
 class WorkerPool(proto.Message):
@@ -1561,24 +1497,21 @@ class WorkerPool(proto.Message):
         DELETING = 3
         DELETED = 4
 
-    name = proto.Field(proto.STRING, number=14)
-
-    project_id = proto.Field(proto.STRING, number=2)
-
-    service_account_email = proto.Field(proto.STRING, number=3)
-
-    worker_count = proto.Field(proto.INT64, number=4)
-
+    name = proto.Field(proto.STRING, number=14,)
+    project_id = proto.Field(proto.STRING, number=2,)
+    service_account_email = proto.Field(proto.STRING, number=3,)
+    worker_count = proto.Field(proto.INT64, number=4,)
     worker_config = proto.Field(proto.MESSAGE, number=16, message="WorkerConfig",)
-
     regions = proto.RepeatedField(proto.ENUM, number=9, enum=Region,)
-
-    create_time = proto.Field(proto.MESSAGE, number=11, message=timestamp.Timestamp,)
-
-    update_time = proto.Field(proto.MESSAGE, number=17, message=timestamp.Timestamp,)
-
-    delete_time = proto.Field(proto.MESSAGE, number=12, message=timestamp.Timestamp,)
-
+    create_time = proto.Field(
+        proto.MESSAGE, number=11, message=timestamp_pb2.Timestamp,
+    )
+    update_time = proto.Field(
+        proto.MESSAGE, number=17, message=timestamp_pb2.Timestamp,
+    )
+    delete_time = proto.Field(
+        proto.MESSAGE, number=12, message=timestamp_pb2.Timestamp,
+    )
     status = proto.Field(proto.ENUM, number=13, enum=Status,)
 
 
@@ -1616,18 +1549,14 @@ class WorkerConfig(proto.Message):
             ``worker``.
     """
 
-    machine_type = proto.Field(proto.STRING, number=1)
-
-    disk_size_gb = proto.Field(proto.INT64, number=2)
-
+    machine_type = proto.Field(proto.STRING, number=1,)
+    disk_size_gb = proto.Field(proto.INT64, number=2,)
     network = proto.Field(proto.MESSAGE, number=3, message="Network",)
-
-    tag = proto.Field(proto.STRING, number=4)
+    tag = proto.Field(proto.STRING, number=4,)
 
 
 class Network(proto.Message):
     r"""Network describes the GCP network used to create workers in.
-
     Attributes:
         project_id (str):
             Project id containing the defined network and subnetwork.
@@ -1644,16 +1573,13 @@ class Network(proto.Message):
             "default" subnetwork is used if empty.
     """
 
-    project_id = proto.Field(proto.STRING, number=1)
-
-    network = proto.Field(proto.STRING, number=2)
-
-    subnetwork = proto.Field(proto.STRING, number=3)
+    project_id = proto.Field(proto.STRING, number=1,)
+    network = proto.Field(proto.STRING, number=2,)
+    subnetwork = proto.Field(proto.STRING, number=3,)
 
 
 class CreateWorkerPoolRequest(proto.Message):
     r"""Request to create a new ``WorkerPool``.
-
     Attributes:
         parent (str):
             ID of the parent project.
@@ -1661,14 +1587,12 @@ class CreateWorkerPoolRequest(proto.Message):
             ``WorkerPool`` resource to create.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
-
+    parent = proto.Field(proto.STRING, number=1,)
     worker_pool = proto.Field(proto.MESSAGE, number=2, message="WorkerPool",)
 
 
 class GetWorkerPoolRequest(proto.Message):
     r"""Request to get a ``WorkerPool`` with the specified name.
-
     Attributes:
         name (str):
             The field will contain name of the resource
@@ -1676,12 +1600,11 @@ class GetWorkerPoolRequest(proto.Message):
             "projects/project-1/workerPools/workerpool-name".
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class DeleteWorkerPoolRequest(proto.Message):
     r"""Request to delete a ``WorkerPool``.
-
     Attributes:
         name (str):
             The field will contain name of the resource
@@ -1689,12 +1612,11 @@ class DeleteWorkerPoolRequest(proto.Message):
             "projects/project-1/workerPools/workerpool-name".
     """
 
-    name = proto.Field(proto.STRING, number=1)
+    name = proto.Field(proto.STRING, number=1,)
 
 
 class UpdateWorkerPoolRequest(proto.Message):
     r"""Request to update a ``WorkerPool``.
-
     Attributes:
         name (str):
             The field will contain name of the resource
@@ -1704,25 +1626,22 @@ class UpdateWorkerPoolRequest(proto.Message):
             ``WorkerPool`` resource to update.
     """
 
-    name = proto.Field(proto.STRING, number=2)
-
+    name = proto.Field(proto.STRING, number=2,)
     worker_pool = proto.Field(proto.MESSAGE, number=3, message="WorkerPool",)
 
 
 class ListWorkerPoolsRequest(proto.Message):
     r"""Request to list ``WorkerPools``.
-
     Attributes:
         parent (str):
             ID of the parent project.
     """
 
-    parent = proto.Field(proto.STRING, number=1)
+    parent = proto.Field(proto.STRING, number=1,)
 
 
 class ListWorkerPoolsResponse(proto.Message):
     r"""Response containing existing ``WorkerPools``.
-
     Attributes:
         worker_pools (Sequence[google.cloud.devtools.cloudbuild_v1.types.WorkerPool]):
             ``WorkerPools`` for the project.
